summaryrefslogtreecommitdiff
path: root/source3/lib/smbconf/smbconf.c
diff options
context:
space:
mode:
Diffstat (limited to 'source3/lib/smbconf/smbconf.c')
-rw-r--r--source3/lib/smbconf/smbconf.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/lib/smbconf/smbconf.c b/source3/lib/smbconf/smbconf.c
index 47254be68d..660cb6f79f 100644
--- a/source3/lib/smbconf/smbconf.c
+++ b/source3/lib/smbconf/smbconf.c
@@ -792,7 +792,7 @@ struct smbconf_ops smbconf_ops_reg = {
* that should be passed around in subsequent calls to the other
* smbconf functions.
*
* After the work with the configuration is completed, smbconf_close()
* should be called.
*/
WERROR smbconf_init(TALLOC_CTX *mem_ctx, struct smbconf_ctx **conf_ctx)
@@ -829,7 +829,7 @@ fail:
/**
* Close the configuration.
*/
-void smbconf_close(struct smbconf_ctx *ctx)
+void smbconf_shutdown(struct smbconf_ctx *ctx)
{
/* this also closes the registry (by destructor): */
TALLOC_FREE(ctx);
@@ -792,7 +792,7 @@ struct smbconf_ops smbconf_ops_reg = {
* smbconf functions.
*
- * After the work with the configuration is completed, smbconf_close()
+ * After the work with the configuration is completed, smbconf_shutdown()
* should be called.
*/